@@ -3,6 +3,9 @@ from bs4 import BeautifulSoup
 import os
 import logging
 import logging.handlers
+import urllib3
+
+urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 host = 'http://www.arbitr.ru'
 url = host+'/as/'
@@ -86,7 +89,7 @@ def parser_people_links(link):
     if link.find('krasnoyarsk') != -1:
         html = f.get_html(link+addition+addition_kr)
     else:
-        html = f.get_html(link + addition)
+        html = f.get_html(link+addition)
     soup = BeautifulSoup(html.text, 'html.parser')
     soup = soup.find('div', class_='l-columns')
     if soup != None:
@@ -118,7 +121,10 @@ def parser_people_links(link):
         for sou in soup1:
             sou = sou.find('a', class_='item_link')
             if sou != None:
-                links.append({"link":link[:-1] + sou.get('href'), "name": sou.get_text()})
+                if sou.get('href').find(".ru") == -1:
+                    links.append({"link":link[:-1] + sou.get('href'), "name": sou.get_text()})
+                else:
+                    links.append({"link":sou.get('href'), "name": sou.get_text()})
     else:
         links = None
     return links
